pub struct CursorPos {
pub x: u32,
pub y: u32,
}Expand description
A cursor position handed to InkRoot::set_cursor. Mirrors ink’s
CursorPosition (cursor-helpers.ts:3-6, {x, y}). None at the call site
mirrors setCursorPosition(undefined).
Fields
x: u32y: u32Trait Implementations
Sourceimpl FromNapiValue for CursorPos
impl FromNapiValue for CursorPos
Sourceunsafe fn from_napi_value(
env: napi_env,
napi_val: napi_value,
) -> Result<CursorPos>
unsafe fn from_napi_value( env: napi_env, napi_val: napi_value, ) -> Result<CursorPos>
This function called to convert napi values to native rust values Read more
fn from_unknown(value: Unknown<'_>) -> Result<Self, Error>
Sourceimpl ToNapiValue for CursorPos
impl ToNapiValue for CursorPos
Sourceunsafe fn to_napi_value(env: napi_env, val: CursorPos) -> Result<napi_value>
unsafe fn to_napi_value(env: napi_env, val: CursorPos) -> Result<napi_value>
This function called to convert rust values to napi values Read more
fn into_unknown(self, env: &Env) -> Result<Unknown<'_>, Error>
Sourceimpl ValidateNapiValue for CursorPos
impl ValidateNapiValue for CursorPos
Sourceunsafe fn validate(
env: *mut napi_env__,
napi_val: *mut napi_value__,
) -> Result<*mut napi_value__, Error>
unsafe fn validate( env: *mut napi_env__, napi_val: *mut napi_value__, ) -> Result<*mut napi_value__, Error>
This function called to validate whether napi value passed to rust is valid type. Read more